DMS

Struct DMS 

pub struct DMS { /* private fields */ }
Reader and Writer for degrees, minutes, seconds format, e.g 50°53'39.70''N 10°57'19.23''E.

Degrees, minutes, and seconds are parsed with any number of digits. Optional space characters are accepted between latitude and longitude, between numeric values and the ‘°’, “'”, “''”, and the hemisphere letters.

Implementations

Source

impl DMS

pub fn from_reader(reader: &dyn Reader) -> Self

Construct DMS type from Reader’s Coordinates.